@@ -38,7 +38,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.040'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 use Mouse;
 
@@ -180,9 +180,9 @@ sub add
     if (defined $term_namespace) {
       my $existing_term_by_name = $terms_by_cv_name->{$term_namespace}->{$name};
       if ($existing_term_by_name && $existing_term_by_name != $term) {
-        warn qq(more than one Term with the name "$name" in namespace "$term_namespace" -\n) .
-          "existing:\n" . $term->to_string() . "\n\nand:\n" .
-          $terms_by_cv_name->{$term_namespace}->{$name}->to_string() . "\n\n";
+        warn qq(more than one Term with the name "$name" in namespace "$term_namespace":\n) .
+          "  " . $term->id() . "\nand:\n  " .
+          $terms_by_cv_name->{$term_namespace}->{$name}->id() . "\n\n";
       } else {
         $terms_by_cv_name->{$term_namespace}->{$name} = $term;
       }
